// Includes
#include <stddef.h>
#include "stm32f0xx_conf.h"


/*USE_STDPERIPH_DRIVER*/

static __IO uint32_t TimingDelay;

/* Private function prototypes -----------------------------------------------*/
void _delay_ms(__IO uint32_t nTime);

void setup_TestPin(void) {

	GPIO_InitTypeDef GPIO_InitStructure;

	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);

	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
	GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
	GPIO_Init(GPIOA, &GPIO_InitStructure);


}

void TIM2_IRQHandler(void) {

//	uart1_puts("\r\n> ");
	TIM_ClearITPendingBit(TIM2, TIM_IT_Update );
}

void initTim2(void) {

	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM6, ENABLE);

	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);

	TIM_TimeBaseInitTypeDef timerSt;
	TIM_TimeBaseStructInit(&timerSt);
	timerSt.TIM_Prescaler = 10000 - 1;
	timerSt.TIM_Period = (SystemCoreClock / 10000) - 1;
	TIM_TimeBaseInit(TIM2, &timerSt);

	NVIC_InitTypeDef nvic;
	nvic.NVIC_IRQChannel = TIM2_IRQn;
	nvic.NVIC_IRQChannelCmd = ENABLE;
	nvic.NVIC_IRQChannelPriority = 3;
	NVIC_Init(&nvic);
	TIM_ITConfig(TIM2, TIM_IT_Update, ENABLE);

	TIM_Cmd(TIM2, ENABLE);
}

int main(void) {

	SystemCoreClockUpdate();

	if (SysTick_Config(SystemCoreClock / 1000)) {
		/* Capture error */
		while (1)
			;
	}

	setup_TestPin();
	initTim2();


	while (1) {


	}
	return 0;
}






/**
 * @brief  Inserts a delay time.
 * @param  nTime: specifies the delay time length, in milliseconds.
 * @retval None
 */
void _delay_ms(__IO uint32_t nTime) {
	TimingDelay = nTime;

	while (TimingDelay != 0)
		;
}


/**
 * @brief  Decrements the TimingDelay variable.
 * @param  None
 * @retval None
 */
void TimingDelay_Decrement(void) {
	if (TimingDelay != 0x00) {
		TimingDelay--;
	}
}


/***************************************************************/
void assert_failed(uint8_t* file, uint32_t line) {
	while (1) {
		;
	}

}

/**
* Cortex M0 - STM32F0 Discovery board code spew out one of the clocks on PA.8
*/
void OutputMCO() {
	GPIO_InitTypeDef GPIO_InitStructure;

	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE);

	/* Output clock on MCO pin ---------------------------------------------*/

	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF;
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
	GPIO_Init(GPIOA, &GPIO_InitStructure);

	// pick one of the clocks to spew
	//RCC_MCOConfig(RCC_MCOSource_SYSCLK); // Put on MCO pin the: System clock selected
	//RCC_MCOConfig(RCC_MCOSource_HSE); // Put on MCO pin the: freq. of external crystal
	RCC_MCOConfig(RCC_MCOSource_PLLCLK_Div2); // Put on MCO pin the: System clock selected
}
